function ne = notequal(m1, m2, tolIn)
% notequal: Check if matrix elements differ by more than a tolerance
% ---------------------------------------
% IN:
%   m1, m2
%       two matrices to be compared; any may be scalar
%   tolIn
%       tolerance; optional
% OUT:
%   1 if not equal; 0 if equal

% ERRORS:
%
% TEST:
%
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

% *******  INPUT CHECK  ********

    if nargin < 3
        tol = 1e-9;
    else
        tol = tolIn;
    end

    if isempty(m1)
        abort('m1 empty')
    end
    % ** Don't blow up if one is a scalar
    if any( size(m1) ~= size(m2) )  &  any( size(m1) ~= [1,1] ) ...
        &  any( size(m2) ~= [1,1] )
        abort('Matrices not conformable')
    end


    ne = any( any( abs(m1-m2) > tol ) );



% *** end function ***

