function optV = optset(inV,defaultV,useDefault)
% optset: Set vector of options to input values or defaults.
% ---------------------------------------
% TASK:
%   Inputs are a vector of options and their defaults. Whenever a value is
%   either omitted or set to a value indicating that the default should be
%   used, return the default. Otherwise return the input value.
% IN:
%   inV         vector of inputs
%   defaultV    vector of defaults
%   useDefault  value that indicates that default should be used (inV(i) = useDefault => replace by defaultV(i))
% OUT:
%   vector of input or default values


% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

    optV = defaultV;
    if isempty(inV)
        return
    end

    n = length(inV);
    if n > length(defaultV)
        abort('OptSet: Too long input vector')
    end

    for i = 1 : n
        if inV(i) ~= useDefault
            optV(i) = inV(i);
        end
    end

% *** end function ***
